@@ -4,6 +4,7 @@ from persistent.mapping import PersistentMapping
 from plone import api
 from plone.i18n.normalizer import IIDNormalizer
 from plone.memoize import ram
+from plone.memoize.forever import _memos
 from plone.memoize.instance import Memojito
 from plone.memoize.interfaces import ICacheChooser
 from Products.CMFPlone.utils import base_hasattr
@@ -52,6 +53,11 @@ def cleanRamCacheFor(methodId):
     thecache.ramcache.invalidate(methodId)
 
 
+def cleanForeverCache():
+    """Clean cache using the @forever.memoize decorator."""
+    _memos.clear()
+
+
 def get_cachekey_volatile(name, method=None):
     """Helper for using a volatile corresponding to p_name
        to be used as cachekey stored in a volatile.
