@@ -16,6 +16,7 @@ from imio.helpers.content import get_state_infos
 from imio.helpers.content import get_transitions
 from imio.helpers.content import get_user_fullname
 from imio.helpers.content import get_vocab
+from imio.helpers.content import get_vocab_values
 from imio.helpers.content import normalize_name
 from imio.helpers.content import object_ids
 from imio.helpers.content import object_values
@@ -69,14 +70,14 @@ class TestContentModule(IntegrationTestCase):
         self.assertEqual(self.portal, get_object(obj_path='/'))
 
         # Give id
-        self.assertEqual(obj, get_object(id='mydoc'))
+        self.assertEqual(obj, get_object(oid='mydoc'))
         # Give title
         self.assertEqual(obj, get_object(title='My document'))
         # Give type
-        self.assertEqual(obj, get_object(type='Document', id='mydoc'))
+        self.assertEqual(obj, get_object(ptype='Document', oid='mydoc'))
         # All parameters
-        self.assertEqual(obj, get_object(type='Document', id='mydoc', title='My document', parent='folder'))
-        self.assertEqual(obj, get_object(type='Document', id='mydoc', title='My document', obj_path='folder/mydoc'))
+        self.assertEqual(obj, get_object(ptype='Document', oid='mydoc', title='My document', parent='folder'))
+        self.assertEqual(obj, get_object(ptype='Document', oid='mydoc', title='My document', obj_path='folder/mydoc'))
 
     def test_transitions(self):
         obj = api.content.create(container=self.portal.folder, id='mydoc', type='Document')
@@ -324,6 +325,20 @@ class TestContentModule(IntegrationTestCase):
         vocab = get_vocab(None, 'plone.app.vocabularies.PortalTypes', only_factory=True)
         self.assertTrue(isinstance(vocab, PortalTypesVocabulary))
 
+    def test_get_vocab_values(self):
+        values = get_vocab_values(self.portal, 'plone.app.vocabularies.PortalTypes')
+        self.assertTrue("testingtype" in values)
+        self.assertTrue("Folder" in values)
+        self.assertTrue("Document" in values)
+        values = get_vocab_values(self.portal, 'plone.app.vocabularies.PortalTypes', attr_name='value')
+        self.assertTrue("testingtype" in values)
+        self.assertTrue("Folder" in values)
+        self.assertTrue("Document" in values)
+        values = get_vocab_values(self.portal, 'plone.app.vocabularies.PortalTypes', attr_name='title')
+        self.assertTrue(u"Testing type" in values)
+        self.assertTrue(u"Folder" in values)
+        self.assertTrue(u"Page" in values)
+
     def test_get_state_infos(self):
         self.portal.portal_workflow.setChainForPortalTypes(('Document', ), ('intranet_workflow', ))
         obj = api.content.create(container=self.portal.folder, id='mydoc', title='My document', type='Document')
